summaryrefslogtreecommitdiff
path: root/web/share/js/kvm/keyboard.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/share/js/kvm/keyboard.js')
-rw-r--r--web/share/js/kvm/keyboard.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/share/js/kvm/keyboard.js b/web/share/js/kvm/keyboard.js
index 7c632d40..49e9c76c 100644
--- a/web/share/js/kvm/keyboard.js
+++ b/web/share/js/kvm/keyboard.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -123,7 +123,7 @@ export function Keyboard(__recordWsEvent) {
}
} else {
if (is_captured) {
- title = "Keyboard captured, Pi-KVM offline";
+ title = "Keyboard captured, PiKVM offline";
}
}
$("hid-keyboard-led").className = led;
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #